@@ -42,7 +42,6 @@ metadata_ext = ".metadata.json"
 
 
 class Metadata:
-
     __slots__ = ["name", "norm_name", "version", "homepage", "trusted", "sha256"]
 
     def __init__(
@@ -63,7 +62,6 @@ class Metadata:
 
 
 class Pkg:
-
     __slots__ = ["file", "metadata"]
 
     def __init__(self, file_: str, metadata: Metadata) -> None:
@@ -233,10 +231,13 @@ def download(
     abi: Optional[str] = None,
     no_build_isolation: Optional[bool] = False,
     pip: str = "pip",
+    extra_index_url: Optional[str] = None,
 ) -> None:
     args = [pip, "download", "-d", dest]
     if index_url:
         args += ["--index-url", index_url]
+    if extra_index_url:
+        args += ["--extra-index-url", extra_index_url]
     if proxy:
         args += ["--proxy", proxy]
     if not allow_binary:
@@ -386,7 +387,6 @@ def advertise_print_traceback() -> None:
 
 
 class CmdMeta(abc.ABCMeta):
-
     _registered: ClassVar[Dict[str, Tuple[Type[Cmd], str]]] = {}
 
     def __new__(cls, name: str, bases: Tuple[type, ...], ns: Dict[str, Any]) -> CmdMeta:
@@ -421,7 +421,6 @@ class Cmd(metaclass=CmdMeta):
 
 
 class DownloadDirCmd(Cmd):
-
     __cmd_ignore__ = True
 
     @classmethod
@@ -442,7 +441,6 @@ class DownloadDirCmd(Cmd):
 
 
 class ListCmd(DownloadDirCmd):
-
     __cmd_help__ = "list packages"
 
     @classmethod
@@ -480,14 +478,22 @@ class ListCmd(DownloadDirCmd):
 
 
 class DownloadCmd(DownloadDirCmd):
-
     __cmd_help__ = "download packages and their dependencies"
 
     @classmethod
     def add_args(cls, parser: argparse.ArgumentParser) -> None:
         super().add_args(parser)
         parser.add_argument(
-            "-i", "--index-url", help="base URL of Python Package Index"
+            "-i",
+            "--index-url",
+            help="Base URL of the Python Package Index (default https://pypi.org/simple). "
+            "This should point to a repository compliant with PEP 503 (the simple repository API) "
+            "or a local directory laid out in the same format.",
+        )
+        parser.add_argument(
+            "--extra-index-url",
+            help="Extra URLs of package indexes to use in addition to "
+            "--index-url. Should follow the same rules as --index-url.",
         )
         parser.add_argument(
             "--proxy",
@@ -573,6 +579,7 @@ class DownloadCmd(DownloadDirCmd):
             abi=args.abi,
             no_build_isolation=args.no_build_isolation,
             pip=args.pip_executable,
+            extra_index_url=args.extra_index_url,
         )
         pkgs = args.pkg
         if not pkgs and not args.requirements:
@@ -602,7 +609,6 @@ class DownloadCmd(DownloadDirCmd):
 
 
 class MirrorCmd(DownloadDirCmd):
-
     __cmd_ignore__ = True
 
     @classmethod
@@ -628,7 +634,6 @@ class MirrorCmd(DownloadDirCmd):
 
 
 class CreateCmd(MirrorCmd):
-
     __cmd_help__ = "create the mirror"
 
     def run(self, args: argparse.Namespace) -> None:
@@ -637,7 +642,6 @@ class CreateCmd(MirrorCmd):
 
 
 class DeleteCmd(MirrorCmd):
-
     __cmd_help__ = "delete a package, use at your own risk!"
 
     @classmethod
@@ -726,7 +730,6 @@ class DeleteCmd(MirrorCmd):
 
 
 class WriteMetadataCmd(DownloadDirCmd):
-
     __cmd_name__ = "write-metadata"
     __cmd_help__ = "create metadata files"
 
@@ -743,7 +746,6 @@ class WriteMetadataCmd(DownloadDirCmd):
 
 
 class QueryCmd(Cmd):
-
     __cmd_help__ = "query PyPI to retrieve the versions of a package"
 
     @classmethod
